#!/bin/bash
#################################################################
#
# This file is provided under a dual BSD/GPLv2 license.  When using or 
#   redistributing this file, you may do so under either license.
# 
#   GPL LICENSE SUMMARY
# 
#   Copyright(c) 2007,2008 Intel Corporation. All rights reserved.
# 
#   This program is free software; you can redistribute it and/or modify 
#   it under the terms of version 2 of the GNU General Public License as
#   published by the Free Software Foundation.
# 
#   This program is distributed in the hope that it will be useful, but 
#   WITHOUT ANY WARRANTY; without even the implied warranty of 
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU 
#   General Public License for more details.
# 
#   You should have received a copy of the GNU General Public License 
#   along with this program; if not, write to the Free Software 
#   Foundation, Inc., 51 Franklin St - Fifth Floor, Boston, MA 02110-1301 USA.
#   The full GNU General Public License is included in this distribution 
#   in the file called LICENSE.GPL.
# 
#   Contact Information:
#   Intel Corporation
# 
#   BSD LICENSE 
# 
#   Copyright(c) 2007,2008 Intel Corporation. All rights reserved.
#   All rights reserved.
# 
#   Redistribution and use in source and binary forms, with or without 
#   modification, are permitted provided that the following conditions 
#   are met:
# 
#     * Redistributions of source code must retain the above copyright 
#       notice, this list of conditions and the following disclaimer.
#     * Redistributions in binary form must reproduce the above copyright 
#       notice, this list of conditions and the following disclaimer in 
#       the documentation and/or other materials provided with the 
#       distribution.
#     * Neither the name of Intel Corporation nor the names of its 
#       contributors may be used to endorse or promote products derived 
#       from this software without specific prior written permission.
# 
#   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
#   "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
#   LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR 
#   A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT 
#   OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, 
#   SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT 
#   LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, 
#   DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY 
#   THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT 
#   (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE 
#   OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
# 
# 
#
#################################################################

# Installation script for Asterisk Channel driver

# Prompt for asterisk directory
echo -n "Asterisk installation directory: "
read ASTERISK_DIR


# Prompt for configuration files directory: "
CURRENT_CONF_DIR="/etc/asterisk"
echo -n "Asterisk configuration files are located in [$CURRENT_CONF_DIR]: "
read CONF_DIR

if [ -z "$CONF_DIR" ] ; then
	CONF_DIR=$CURRENT_CONF_DIR
fi


# Copy source file
echo "Installing chan_hss.c ..."

if [ -z "`find $ASTERISK_DIR -name channels`" ] ; then
    echo "Incorrect path!"
    exit 1
else
    install -m 644 chan_hss.c $ASTERISK_DIR/channels/
fi


# Copy configuration file
if [ -z "`find $CONF_DIR -name hss.conf`" ] ; then
    echo "Installing sample hss.conf ..."
    install -m 644 hss.conf $CONF_DIR/
fi


# Remove targets from Makefile
grep -v chan_hss $ASTERISK_DIR/channels/Makefile > $ASTERISK_DIR/channels/Makefile.stripped
echo "" >> $ASTERISK_DIR/channels/Makefile.stripped

# Prompt for echo cancellation
echo -n "Enable echo cancellation? (Yes/No) [Yes]: "
read YESNO

if [ "$YESNO" = "N" -o  "$YESNO" = "n" -o  "$YESNO" = "No" -o  "$YESNO" = "no" ] ; then
    echo "chan_hss.o: ASTCFLAGS+= -I/\$(ICP_ROOT)/Acceleration/include -I/\$(ICP_ROOT)/Acceleration/include/hss" >> $ASTERISK_DIR/channels/Makefile.stripped
    echo "chan_hss.so: LIBS+= \$(ICP_BUILD_OUTPUT)/t1e1_framer_driver.a" >> $ASTERISK_DIR/channels/Makefile.stripped
else
    echo "chan_hss.o: ASTCFLAGS+= -I/\$(ICP_ROOT)/Acceleration/include -I/\$(ICP_ROOT)/Acceleration/include/hss -DUSE_OSLEC_EC" >> $ASTERISK_DIR/channels/Makefile.stripped
    echo "chan_hss.so: LIBS+= \$(ICP_BUILD_OUTPUT)/t1e1_framer_driver.a -lspandsp" >> $ASTERISK_DIR/channels/Makefile.stripped
fi

echo "Updating Makefile ..."
mv -f $ASTERISK_DIR/channels/Makefile.stripped $ASTERISK_DIR/channels/Makefile


echo ""
echo "Installation Complete."